| Title: | Functions to interact with piecepack wiki |
|---|---|
| Description: | Functions to interact with piecepack wiki <https://ludism.org/ppwiki/>. Can download piecepack game metadata and update the Games wiki page. |
| Authors: | Trevor L Davis [aut, cre] (ORCID: <https://orcid.org/0000-0001-6341-4639>), Alex Schroeder [aut] (Uses `wikiput.pl`) |
| Maintainer: | Trevor L Davis <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.2 |
| Built: | 2026-05-20 10:39:34 UTC |
| Source: | https://github.com/piecepackr/ppwicker |
build_games() builds a candidate replacement for Games piecepack wiki page
build_games(update = FALSE)build_games(update = FALSE)
update |
If already downloaded previously, should we download again? |
A character vector with the text for the candidate replacement for Games wiki page.
As a side effect also saves to
file.path(tools::R_user_dir("ppwicker", "cache"), "games.creole").
download_game_metadata() downloads piecepack wiki game metadata.
download_game_metadata(update = FALSE, games = NULL)download_game_metadata(update = FALSE, games = NULL)
update |
If already downloaded previously, should we download again? |
games |
Which games to download metadata for.
If |
Returns a (tibble) data frame of piecepack wiki game metadata.
If no previous download or update = TRUE as a side effect
we download piecepack wiki game metadata to tools::R_user_dir("ppwicker", "cache").
update_games() updates piecepack wiki Games page(s) using wikiput.pl.
update_games( update = FALSE, minor = FALSE, summary = "Update Games page", username = getOption("ppwicker_username"), password = getOption("ppwicker_password"), games = NULL )update_games( update = FALSE, minor = FALSE, summary = "Update Games page", username = getOption("ppwicker_username"), password = getOption("ppwicker_password"), games = NULL )
update |
If already downloaded previously, should we download again? |
minor |
Is this a ‘minor’ wiki edit? |
summary |
Summary for wiki edit |
username |
Piecepack wiki username |
password |
Piecepack wiki password |
games |
If |
You may need a wiki admin password to use this function,
any attempt at using this function with a NULL password failed.